@@ -12,6 +12,7 @@ from revcore_micro.utils import DecimalEncoder
 
 condition_builder = ConditionHandler()
 
+
 class Model:
     table_name = None
     region = 'ap-northeast-1'
@@ -33,12 +34,18 @@ class Model:
         except:
             key_schema = [{'AttributeName': cls.partition_key, 'KeyType': 'HASH'}]
             attrs = [{'AttributeName': cls.partition_key, 'AttributeType': cls.partition_type}]
+
+            if cls.sort_key:
+                key_schema.append({'AttributeName': cls.sort_key, 'KeyType': 'RANGE'})
+                attrs.append({'AttributeName': cls.sort_key, 'AttributeType': cls.sort_type})
+
             indexes = []
             gindexes = []
             kwargs = {'TableName': cls.table_name, 'KeySchema': key_schema, 'AttributeDefinitions': attrs, 'ProvisionedThroughput': {
                 'ReadCapacityUnits': 5,
                 'WriteCapacityUnits': 5
             }}
+
             for key, value in cls.s_indexes.items():
                 schemas = [{'AttributeName': value['pkey'], 'KeyType': 'HASH'}]
                 if not [attr for attr in attrs if attr['AttributeName'] == value['pkey']]:
@@ -58,9 +65,6 @@ class Model:
                         attrs.append({'AttributeName': value['skey'], 'AttributeType': value.get('stype', 'S')})
                 gindexes.append({'IndexName': key, 'KeySchema': schemas, 'Projection': {'ProjectionType': 'ALL'}, 'ProvisionedThroughput': {'ReadCapacityUnits': 5, 'WriteCapacityUnits': 5}})
             
-            if cls.sort_key:
-                key_schema.append({'AttributeName': cls.sort_key, 'KeyType': 'RANGE'})
-                attrs.append({'AttributeName': cls.sort_key, 'AttributeType': cls.sort_type})
 
             if indexes:
                 kwargs['LocalSecondaryIndexes'] = indexes
@@ -93,8 +97,8 @@ class Model:
         try:
             resp = client.get_item(Key=key)
             return cls.deserialize(resp['Item'])
-        except Exception:
-            raise exceptions.InstanceNotFound
+        except KeyError:
+            raise exceptions.InstanceNotFound(table_name=cls.table_name, key=key)
 
     @classmethod
     def put(cls, **kwargs):
