@@ -38,15 +38,10 @@ class Authorizer:
                           force_jwt=True,
                           force_secret=True,
                           force_cert=True):
-        try:
-            context = request.environ['lambda.event']['requestContext']
-        except:
-            context = {'identity': {'apiKeyId': 'test-client'}}
 
-        identity = context.get('identity', {})
         client_id = request.args.get('client_id')
         token = request.args.get('token')
-        client_secret = identity.get('apiKeyId')
+        client_secret = request.headers.get('x-api-key', None)
         cert = request.args.get('certificate')
 
         if (with_client and force_client) or (with_client and client_id):
