@@ -8,7 +8,10 @@ class User:
     def __getattr__(self, value):
         if value.startswith('is_'):
             return value[3:] in self.groups
-        return getattr(self.__class__, value)
+        return getattr(self._meta, value)
 
     def __getitem__(self, key):
         return self._meta[key]
+
+    def __eq__(self, value):
+        return self.sub == value
